Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(114)

Unified Diff: pkg/analyzer/lib/src/generated/ast.dart

Issue 1039713002: Rename MethodInvocation.period to MethodInvocation.operator. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analyzer/lib/src/generated/parser.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/generated/ast.dart
diff --git a/pkg/analyzer/lib/src/generated/ast.dart b/pkg/analyzer/lib/src/generated/ast.dart
index b73b2ab313c757a8b5c833a356745c272022c95c..6fe23edd13b87b81d7c0375ab12979fba594015d 100644
--- a/pkg/analyzer/lib/src/generated/ast.dart
+++ b/pkg/analyzer/lib/src/generated/ast.dart
@@ -1432,7 +1432,7 @@ class AstCloner implements AstVisitor<AstNode> {
@override
MethodInvocation visitMethodInvocation(MethodInvocation node) =>
- new MethodInvocation(cloneNode(node.target), cloneToken(node.period),
+ new MethodInvocation(cloneNode(node.target), cloneToken(node.operator),
cloneNode(node.methodName), cloneNode(node.argumentList));
@override
@@ -2323,7 +2323,7 @@ class AstComparator implements AstVisitor<bool> {
bool visitMethodInvocation(MethodInvocation node) {
MethodInvocation other = _other as MethodInvocation;
return isEqualNodes(node.target, other.target) &&
- isEqualTokens(node.period, other.period) &&
+ isEqualTokens(node.operator, other.operator) &&
isEqualNodes(node.methodName, other.methodName) &&
isEqualNodes(node.argumentList, other.argumentList);
}
@@ -9969,7 +9969,7 @@ class IncrementalAstCloner implements AstVisitor<AstNode> {
@override
MethodInvocation visitMethodInvocation(MethodInvocation node) {
MethodInvocation copy = new MethodInvocation(_cloneNode(node.target),
- _mapToken(node.period), _cloneNode(node.methodName),
+ _mapToken(node.operator), _cloneNode(node.methodName),
_cloneNode(node.argumentList));
copy.propagatedType = node.propagatedType;
copy.staticType = node.staticType;
@@ -11760,10 +11760,11 @@ class MethodInvocation extends Expression {
Expression _target;
/**
- * The period that separates the target from the method name, or `null` if
- * there is no target.
+ * The period that separates the target from the method name in an ordinary
Brian Wilkerson 2015/03/27 16:26:24 I'd prefer the following (because it will expand t
Paul Berry 2015/03/27 16:38:57 Done.
+ * method invocation, or the `..` operator before the method name in a
+ * cascade section, or `null` if there is no target.
*/
- Token period;
+ Token operator;
/**
* The name of the method being invoked.
@@ -11776,11 +11777,11 @@ class MethodInvocation extends Expression {
ArgumentList _argumentList;
/**
* Initialize a newly created method invocation. The [target] and [period] can
* be `null` if there is no target.
*/
- MethodInvocation(Expression target, this.period, SimpleIdentifier methodName,
- ArgumentList argumentList) {
+ MethodInvocation(Expression target, this.operator,
+ SimpleIdentifier methodName, ArgumentList argumentList) {
_target = _becomeParentOf(target);
_methodName = _becomeParentOf(methodName);
_argumentList = _becomeParentOf(argumentList);
@@ -11802,8 +11803,8 @@ class MethodInvocation extends Expression {
Token get beginToken {
if (_target != null) {
return _target.beginToken;
- } else if (period != null) {
- return period;
+ } else if (operator != null) {
+ return operator;
}
return _methodName.beginToken;
}
@@ -11811,7 +11812,7 @@ class MethodInvocation extends Expression {
@override
Iterable get childEntities => new ChildEntities()
..add(_target)
- ..add(period)
+ ..add(operator)
..add(_methodName)
..add(_argumentList);
@@ -11824,7 +11825,7 @@ class MethodInvocation extends Expression {
* that is a [CascadeExpression].
*/
bool get isCascaded =>
- period != null && period.type == TokenType.PERIOD_PERIOD;
+ operator != null && operator.type == TokenType.PERIOD_PERIOD;
/**
* Return the name of the method being invoked.
@@ -11838,6 +11839,28 @@ class MethodInvocation extends Expression {
_methodName = _becomeParentOf(identifier);
}
+ /**
+ * The period that separates the target from the method name in an ordinary
+ * method invocation, or the `..` operator before the method name in a
+ * cascade section, or `null` if there is no target.
+ *
+ * Deprecated: use [operator] instead.
+ */
+ @deprecated
+ Token get period => operator;
+
+ /**
+ * The period that separates the target from the method name in an ordinary
+ * method invocation, or the `..` operator before the method name in a
+ * cascade section, or `null` if there is no target.
+ *
+ * Deprecated: use [operator] instead.
+ */
+ @deprecated
+ void set period(Token value) {
+ operator = value;
+ }
+
@override
int get precedence => 15;
« no previous file with comments | « no previous file | pkg/analyzer/lib/src/generated/parser.dart » ('j') | no next file with comments »
@@ -11776,11 +11777,11 @@ class MethodInvocation extends Expression {
ArgumentList _argumentList;
/**
- * Initialize a newly created method invocation. The [target] and [period] can
- * be `null` if there is no target.
+ * Initialize a newly created method invocation. The [target] and [operator]
+ * can be `null` if there is no target.
*/

Powered by Google App Engine
This is Rietveld 408576698